@@ -919,7 +919,12 @@ gnome_desktop_thumbnail_factory_can_thumbnail (GnomeDesktopThumbnailFactory *fac
 
   g_mutex_lock (&factory->priv->lock);
   if (!gnome_desktop_thumbnail_factory_is_disabled (factory, mime_type))
-    have_script = TRUE;
+    {
+      Thumbnailer *thumb;
+
+      thumb = g_hash_table_lookup (factory->priv->mime_types_map, mime_type);
+      have_script = (thumb != NULL);
+    }
   g_mutex_unlock (&factory->priv->lock);
 
   if (have_script)
@@ -1045,8 +1050,6 @@ gnome_desktop_thumbnail_factory_generate_thumbnail (GnomeDesktopThumbnailFactory
   if (factory->priv->size == GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE)
     size = 256;
 
-  pixbuf = NULL;
-
   pixbuf = get_preview_thumbnail (uri, size);
   if (pixbuf != NULL)
     return pixbuf;
@@ -1071,7 +1074,12 @@ gnome_desktop_thumbnail_factory_generate_thumbnail (GnomeDesktopThumbnailFactory
       data = gnome_desktop_thumbnail_script_exec (script, size, uri, &error);
       if (data)
         {
-          pixbuf = pixbuf_new_from_bytes (data, NULL);
+          pixbuf = pixbuf_new_from_bytes (data, &error);
+          if (!pixbuf)
+            {
+              g_debug ("Could not load thumbnail pixbuf: %s", error->message);
+              g_error_free (error);
+            }
           g_bytes_unref (data);
         }
       else
